import { mapBackground } from '@/models/mapBackground';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { MapBackground } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { z } from 'zod';
import { apiPath } from '../apiPath';

export const getAllBackgroundsByProjectId = createAsyncThunk(
  'models/getAllBackgroundsByProjectId',
  async (projectId: string): Promise<MapBackground[]> => {
    const response = await axiosInstance.get<MapBackground[]>(
      apiPath.getAllBackgroundsByProjectIdQuery(projectId),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(mapBackground));

    return isDataValid ? response.data : [];
  },
);
