import { mapOverlay } from '@/models/mapOverlay';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { MapOverlay } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { z } from 'zod';
import { apiPath } from '../apiPath';

export const getAllPublicOverlaysByProjectId = createAsyncThunk(
  'models/getAllPublicOverlaysByProjectId',
  async (projectId: string): Promise<MapOverlay[]> => {
    const response = await axiosInstance.get<MapOverlay[]>(
      apiPath.getAllOverlaysByProjectIdQuery(projectId, { publicOverlay: true }),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(mapOverlay));

    return isDataValid ? response.data : [];
  },
);
