import { projectSchema } from '@/models/project';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { Project } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { createAsyncThunk } from '@reduxjs/toolkit';

export const getProjectById = createAsyncThunk(
  'project/getProjectById',
  async (id: string): Promise<Project | undefined> => {
    const response = await axiosInstance.get<Project>(`projects/${id}`);

    const isDataValid = validateDataUsingZodSchema(response.data, projectSchema);

    return isDataValid ? response.data : undefined;
  },
);
